==> haskell-yesod-auth-1.6.3-101-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-yesod-auth.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-auth
version: 1.6.3
id: yesod-auth-1.6.3-6HKWNJwsbZXIJOjvU0ZHfM
key: yesod-auth-1.6.3-6HKWNJwsbZXIJOjvU0ZHfM
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
author: Michael Snoyman, Patrick Brisbin
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Authentication for Yesod.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-auth>
category: Web, Yesod
abi: 61113b8ed8b5e343060a5d839238afb6
exposed: True
exposed-modules:
    Yesod.Auth Yesod.Auth.BrowserId Yesod.Auth.Dummy Yesod.Auth.Email
    Yesod.Auth.GoogleEmail2 Yesod.Auth.Hardcoded Yesod.Auth.Message
    Yesod.Auth.OpenId Yesod.Auth.Rpxnow Yesod.Auth.Util.PasswordStore
hidden-modules: Yesod.Auth.Routes
import-dirs: /usr/lib/ghc-8.4.3/site-local/yesod-auth-1.6.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/yesod-auth-1.6.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/yesod-auth-1.6.3
hs-libraries: HSyesod-auth-1.6.3-6HKWNJwsbZXIJOjvU0ZHfM
depends:
    aeson-1.4.0.0-CakggGCi8AH730RFzdp4vh
    authenticate-1.3.4-4SNRpcfuNWgGHHajEnON0I base-4.11.1.0
    base16-bytestring-0.1.1.6-I0igvRcEwRNBMqqPC2yQBh
    base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37 binary-0.8.5.1
    blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028
    blaze-html-0.9.1.1-EgxdH3AtVL83pCluZdDgeJ
    blaze-markup-0.8.2.1-FFkiru1HsegAfMrnqJMDug
    byteable-0.1.1-APABKKN6nDlC3QxQBw4YlY bytestring-0.10.8.2
    conduit-1.3.0.3-69KoIVNx0TVLvOnjPWsVja
    conduit-extra-1.3.0-4j5DaXyKuirAJK9sh69vxz containers-0.5.11.0
    cryptonite-0.25-FWytOeO7q1U1VcDN91QFfT
    data-default-0.7.1.1-6pNGRUfj5nU7unWVd8ajT0
    email-validate-2.3.2.6-Iqn6BWieuUi7RVtiMSSSun
    file-embed-0.0.11-F0DApYaRQMkAdYGXjkQy01
    http-client-0.5.13.1-8VGZtvml4R5EgKWuNogbLU
    http-client-tls-0.3.5.3-Ae3PM2U2f4vJ6QqOCuwXIL
    http-conduit-2.3.2-Fc3FewYwyrU2z9C3xj29pG
    http-types-0.12.1-BvzC7WDeWNh7Q1bvrgnPmB
    memory-0.14.16-FrHKJ6EcQ5I95PPEhrgDqk
    mime-mail-0.4.14-GLaV7oAqZfiAlrqdTagy2f
    network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9
    nonce-1.0.7-5swjpXLqxQ5K94w8AeF6F3
    persistent-2.8.2-80hCJ3YiuUWKQIuntVh6t
    persistent-template-2.5.4-AtW1Hy0z9crJ1HQWYYKkIN
    random-1.1-9LLJAJa4iQFLJiLXBOBXBV
    resourcet-1.2.1-I5oi84Fds3fEsALgoQoNDA
    safe-0.3.17-HEmZRpXGD3s2ywM3rHJ1ur
    shakespeare-2.0.17-A8dRnnHCPSxH0Ym0oDmkvY template-haskell-2.13.0.0
    text-1.2.3.0 time-1.8.0.2 transformers-0.5.5.0
    unliftio-0.2.8.0-EnZ3At7VrLC8UzSwZrg5p4
    unliftio-core-0.1.2.0-900TPot3SR34dceIcVaslS
    unordered-containers-0.2.9.0-KfM11vwfv9j3BnvMvjdQDd
    wai-3.2.1.2-5X5AWGcLTJMBYHkaS1XJdn
    yesod-core-1.6.6-nfcvEotumGCGd0HidcnuE
    yesod-form-1.6.2-JXCIkJfwIOR9FdpTcZyltk
    yesod-persistent-1.6.0-HV6ZvElr01U5xZz98mFFd1
abi-depends: aeson-1.4.0.0-CakggGCi8AH730RFzdp4vh=7bc5561c9bccdf225964aec1dc0920a0
             authenticate-1.3.4-4SNRpcfuNWgGHHajEnON0I=3663b6fe081bc456042732086bf8002b
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             base16-bytestring-0.1.1.6-I0igvRcEwRNBMqqPC2yQBh=bba358ad6d6aaa259e18cb7e07ede79c
             base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37=65adc4f5f54a1c07291b4ebc49756c05
             binary-0.8.5.1=0c28e4e382bf1405fd468e0d2a2b58e5
             blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028=f952a1ec5abae3e4435518edbfd82e4e
             blaze-html-0.9.1.1-EgxdH3AtVL83pCluZdDgeJ=26d7d7bc6469699c9d8f038081c294ce
             blaze-markup-0.8.2.1-FFkiru1HsegAfMrnqJMDug=71b515c6e3bfb99ff0075cc129b1fc3b
             byteable-0.1.1-APABKKN6nDlC3QxQBw4YlY=cdb4e7359967ea10cd00ae1d3fab6945
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             conduit-1.3.0.3-69KoIVNx0TVLvOnjPWsVja=95a17956f651b4cddf6ae026fd262ccd
             conduit-extra-1.3.0-4j5DaXyKuirAJK9sh69vxz=7890d00a08a10fe933f51da56482ec4e
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             cryptonite-0.25-FWytOeO7q1U1VcDN91QFfT=b157b67f4f829eb7de058ea2d8709fe0
             data-default-0.7.1.1-6pNGRUfj5nU7unWVd8ajT0=e2403b7ea90422302496191f03ca1dc3
             email-validate-2.3.2.6-Iqn6BWieuUi7RVtiMSSSun=2349e72bc1b9e9382c16b1ddb0386749
             file-embed-0.0.11-F0DApYaRQMkAdYGXjkQy01=46cca7bb0548d8ae1738b3dc324c7440
             http-client-0.5.13.1-8VGZtvml4R5EgKWuNogbLU=731e662bb8eff5482969dab5518da667
             http-client-tls-0.3.5.3-Ae3PM2U2f4vJ6QqOCuwXIL=2eb76040ee6f49021be8be5732a1da2f
             http-conduit-2.3.2-Fc3FewYwyrU2z9C3xj29pG=587475ff466ed617e153f3e7b1f159a8
             http-types-0.12.1-BvzC7WDeWNh7Q1bvrgnPmB=302ec39836eeed635681d48972d58b60
             memory-0.14.16-FrHKJ6EcQ5I95PPEhrgDqk=a0627d5d7afb3952e7ea8a317c372f9d
             mime-mail-0.4.14-GLaV7oAqZfiAlrqdTagy2f=b695f31ceaced253afa318a64a996761
             network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9=4ea8f0efa7a1ade0af4e9ce0cffcff8c
             nonce-1.0.7-5swjpXLqxQ5K94w8AeF6F3=8fb310270132cddb79dfc4c4d28724dc
             persistent-2.8.2-80hCJ3YiuUWKQIuntVh6t=5b689317a27b1b8b77e5e821541803cf
             persistent-template-2.5.4-AtW1Hy0z9crJ1HQWYYKkIN=a49af464aaf9c0727a2dc3524964374b
             random-1.1-9LLJAJa4iQFLJiLXBOBXBV=2cade9e72fa19fe7a43e5ace84505d9f
             resourcet-1.2.1-I5oi84Fds3fEsALgoQoNDA=dcbdc81671b5884f063aea7a644e0575
             safe-0.3.17-HEmZRpXGD3s2ywM3rHJ1ur=42026212d0dad8beaed25fde58365be8
             shakespeare-2.0.17-A8dRnnHCPSxH0Ym0oDmkvY=3def54b7a0889df4443c640e3aaa182e
             template-haskell-2.13.0.0=ac7dfd04924d4ebfa90a119ad22a36cc
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             time-1.8.0.2=042930fb6746cbaf3bc794f817f8a6b2
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             unliftio-0.2.8.0-EnZ3At7VrLC8UzSwZrg5p4=7631465c11492fd2c6759a99a65ec5d6
             unliftio-core-0.1.2.0-900TPot3SR34dceIcVaslS=b3bd63f18add30d59629e9599623cc96
             unordered-containers-0.2.9.0-KfM11vwfv9j3BnvMvjdQDd=4d1dd6bd73dbf55dc13ef767664a6e82
             wai-3.2.1.2-5X5AWGcLTJMBYHkaS1XJdn=e1fd23653e3ca2821004ffc56c811100
             yesod-core-1.6.6-nfcvEotumGCGd0HidcnuE=e2d5b53dd8de47cd3d777649a4a3f231
             yesod-form-1.6.2-JXCIkJfwIOR9FdpTcZyltk=4e5dc11a604e0e0240a18f3ca8d30b04
             yesod-persistent-1.6.0-HV6ZvElr01U5xZz98mFFd1=3069e6796a0cf80d82356ff81f2d002c
haddock-interfaces: /usr/share/doc/haskell-yesod-auth/html/yesod-auth.haddock
haddock-html: /usr/share/doc/haskell-yesod-auth/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yesod-auth-1.6.4.1-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-yesod-auth.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-auth
version: 1.6.4.1
id: yesod-auth-1.6.4.1-3bct0SXxqEA1okLcbScJtW
key: yesod-auth-1.6.4.1-3bct0SXxqEA1okLcbScJtW
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
author: Michael Snoyman, Patrick Brisbin
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Authentication for Yesod.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-auth>
category: Web, Yesod
abi: 8f5482201b99a34552f5dcb3430bd4b0
exposed: True
exposed-modules:
    Yesod.Auth Yesod.Auth.BrowserId Yesod.Auth.Dummy Yesod.Auth.Email
    Yesod.Auth.GoogleEmail2 Yesod.Auth.Hardcoded Yesod.Auth.Message
    Yesod.Auth.OpenId Yesod.Auth.Rpxnow Yesod.Auth.Util.PasswordStore
hidden-modules: Yesod.Auth.Routes
import-dirs: /usr/lib/ghc-8.4.3/site-local/yesod-auth-1.6.4.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/yesod-auth-1.6.4.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/yesod-auth-1.6.4.1
hs-libraries: HSyesod-auth-1.6.4.1-3bct0SXxqEA1okLcbScJtW
depends:
    aeson-1.4.0.0-EgUTCbIlE19378rsR2i9zV
    authenticate-1.3.4-Li7hg33ZNC93EZrnDCWu7O base-4.11.1.0
    base16-bytestring-0.1.1.6-I0igvRcEwRNBMqqPC2yQBh
    base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37 binary-0.8.5.1
    blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028
    blaze-html-0.9.1.1-EgxdH3AtVL83pCluZdDgeJ
    blaze-markup-0.8.2.1-FFkiru1HsegAfMrnqJMDug bytestring-0.10.8.2
    conduit-1.3.0.3-69KoIVNx0TVLvOnjPWsVja
    conduit-extra-1.3.0-4j5DaXyKuirAJK9sh69vxz containers-0.5.11.0
    cryptonite-0.25-FWytOeO7q1U1VcDN91QFfT
    data-default-0.7.1.1-ANph70WEdAe9A1H2IGNxHn
    email-validate-2.3.2.7-6xChNHpvgMQC6fcxPOTEKP
    file-embed-0.0.11-F0DApYaRQMkAdYGXjkQy01
    http-client-0.5.13.1-8VGZtvml4R5EgKWuNogbLU
    http-client-tls-0.3.5.3-KHqdrg1m2Ik3YpAeWMZiTu
    http-conduit-2.3.2-1aZWoMRsYRpKfDlvvbX8BU
    http-types-0.12.1-BvzC7WDeWNh7Q1bvrgnPmB
    memory-0.14.16-FrHKJ6EcQ5I95PPEhrgDqk
    network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9
    nonce-1.0.7-5swjpXLqxQ5K94w8AeF6F3
    persistent-2.8.2-9m4AzNCUKLp575AVOxs94D
    random-1.1-9LLJAJa4iQFLJiLXBOBXBV
    safe-0.3.17-HEmZRpXGD3s2ywM3rHJ1ur
    shakespeare-2.0.17-1zc3dDfWWbuHYwWDgwWW3X template-haskell-2.13.0.0
    text-1.2.3.0 time-1.8.0.2 transformers-0.5.5.0
    unliftio-0.2.8.0-EnZ3At7VrLC8UzSwZrg5p4
    unliftio-core-0.1.2.0-900TPot3SR34dceIcVaslS
    unordered-containers-0.2.9.0-KfM11vwfv9j3BnvMvjdQDd
    wai-3.2.1.2-5X5AWGcLTJMBYHkaS1XJdn
    yesod-core-1.6.6-jOod1PtW2V5YRpDWrqi9n
    yesod-form-1.6.2-HhAIzCd3z5MHDo4fDY9epU
    yesod-persistent-1.6.0-L6t053YrtGzFDXiDD3vXzr
abi-depends: aeson-1.4.0.0-EgUTCbIlE19378rsR2i9zV=8e4d597de977510ba6167651bfbacc4c
             authenticate-1.3.4-Li7hg33ZNC93EZrnDCWu7O=244aa6d0905e9e107c092cae662b3e31
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             base16-bytestring-0.1.1.6-I0igvRcEwRNBMqqPC2yQBh=bba358ad6d6aaa259e18cb7e07ede79c
             base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37=65adc4f5f54a1c07291b4ebc49756c05
             binary-0.8.5.1=0c28e4e382bf1405fd468e0d2a2b58e5
             blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028=f952a1ec5abae3e4435518edbfd82e4e
             blaze-html-0.9.1.1-EgxdH3AtVL83pCluZdDgeJ=26d7d7bc6469699c9d8f038081c294ce
             blaze-markup-0.8.2.1-FFkiru1HsegAfMrnqJMDug=71b515c6e3bfb99ff0075cc129b1fc3b
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             conduit-1.3.0.3-69KoIVNx0TVLvOnjPWsVja=95a17956f651b4cddf6ae026fd262ccd
             conduit-extra-1.3.0-4j5DaXyKuirAJK9sh69vxz=7890d00a08a10fe933f51da56482ec4e
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             cryptonite-0.25-FWytOeO7q1U1VcDN91QFfT=b157b67f4f829eb7de058ea2d8709fe0
             data-default-0.7.1.1-ANph70WEdAe9A1H2IGNxHn=02e9419e0e877fc1db7c56d6f64866aa
             email-validate-2.3.2.7-6xChNHpvgMQC6fcxPOTEKP=3049cf06f50f8453b7b3068a0094e614
             file-embed-0.0.11-F0DApYaRQMkAdYGXjkQy01=46cca7bb0548d8ae1738b3dc324c7440
             http-client-0.5.13.1-8VGZtvml4R5EgKWuNogbLU=731e662bb8eff5482969dab5518da667
             http-client-tls-0.3.5.3-KHqdrg1m2Ik3YpAeWMZiTu=f698c6d730379fc5e56cf2dac8ec304b
             http-conduit-2.3.2-1aZWoMRsYRpKfDlvvbX8BU=d9058125d1363db51383405558893120
             http-types-0.12.1-BvzC7WDeWNh7Q1bvrgnPmB=302ec39836eeed635681d48972d58b60
             memory-0.14.16-FrHKJ6EcQ5I95PPEhrgDqk=a0627d5d7afb3952e7ea8a317c372f9d
             network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9=4ea8f0efa7a1ade0af4e9ce0cffcff8c
             nonce-1.0.7-5swjpXLqxQ5K94w8AeF6F3=8fb310270132cddb79dfc4c4d28724dc
             persistent-2.8.2-9m4AzNCUKLp575AVOxs94D=2423c14f526c2bdb9126ab0c7c5b8bc1
             random-1.1-9LLJAJa4iQFLJiLXBOBXBV=2cade9e72fa19fe7a43e5ace84505d9f
             safe-0.3.17-HEmZRpXGD3s2ywM3rHJ1ur=42026212d0dad8beaed25fde58365be8
             shakespeare-2.0.17-1zc3dDfWWbuHYwWDgwWW3X=bc2f8cae2e74db2b0c0118afec686833
             template-haskell-2.13.0.0=ac7dfd04924d4ebfa90a119ad22a36cc
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             time-1.8.0.2=042930fb6746cbaf3bc794f817f8a6b2
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             unliftio-0.2.8.0-EnZ3At7VrLC8UzSwZrg5p4=7631465c11492fd2c6759a99a65ec5d6
             unliftio-core-0.1.2.0-900TPot3SR34dceIcVaslS=b3bd63f18add30d59629e9599623cc96
             unordered-containers-0.2.9.0-KfM11vwfv9j3BnvMvjdQDd=4d1dd6bd73dbf55dc13ef767664a6e82
             wai-3.2.1.2-5X5AWGcLTJMBYHkaS1XJdn=e1fd23653e3ca2821004ffc56c811100
             yesod-core-1.6.6-jOod1PtW2V5YRpDWrqi9n=0a7b5f8ddfaf58a4e81f289d548e0776
             yesod-form-1.6.2-HhAIzCd3z5MHDo4fDY9epU=d3b02f7c0674ccbdfc504e58a31a5d42
             yesod-persistent-1.6.0-L6t053YrtGzFDXiDD3vXzr=ca0f952f8e5258bd8709faaa7440709a
haddock-interfaces: /usr/share/doc/haskell-yesod-auth/html/yesod-auth.haddock
haddock-html: /usr/share/doc/haskell-yesod-auth/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
